@@ -3,8 +3,10 @@ import json
 from django.template import Library
 from django.template.base import Node
 from django.core.exceptions import ImproperlyConfigured
+from django.template.loader import render_to_string
 from django.utils.safestring import mark_safe
-from djangular.core.urlresolvers import get_all_remote_methods, get_current_remote_methods
+from djangular.core.urlresolvers import get_all_remote_methods, get_current_remote_methods, get_urls
+
 register = Library()
 
 
@@ -42,3 +44,7 @@ def djng_current_rmi(context):
     the AngularJS provider, such as ``djangoRMIProvider.configure({­% djng_current_rmi %­});``
     """
     return mark_safe(json.dumps(get_current_remote_methods(context['view'])))
+
+@register.simple_tag(name='load_djng_urls')
+def djng_urls():
+    return mark_safe(json.dumps(get_urls()))
